pub struct AfkRewardsByLevel {
pub chapter_level: i64,
pub currency_rates: Vec<CurrencyRate>,
pub bonus_weights: NonEmptyVec<AfkRewardBonusWeight>,
}Fields
chapter_level: i64currency_rates: Vec<CurrencyRate>bonus_weights: NonEmptyVec<AfkRewardBonusWeight>Trait Implementations
Sourceimpl Clone for AfkRewardsByLevel
impl Clone for AfkRewardsByLevel
Sourcefn clone(&self) -> AfkRewardsByLevel
fn clone(&self) -> AfkRewardsByLevel
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AfkRewardsByLevel
impl Debug for AfkRewardsByLevel
Sourceimpl<'de> Deserialize<'de> for AfkRewardsByLevel
impl<'de> Deserialize<'de> for AfkRewardsByLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AfkRewardsByLevel
impl JsonSchema for AfkRewardsByLevel
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AfkRewardsByLevel
impl Serialize for AfkRewardsByLevel
Sourceimpl Tsify for AfkRewardsByLevel
impl Tsify for AfkRewardsByLevel
const DECL: &'static str = "export interface AfkRewardsByLevel {\n chapter_level: number;\n currency_rates: CurrencyRate[];\n bonus_weights: NonEmptyVec<AfkRewardBonusWeight>;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>