pub struct AfkRewardsSettings {
pub bundle_id: BundleId,
pub min_required_time_sec: u64,
pub max_possible_time_sec: u64,
pub bonus_calculation_rate_sec: NonZeroU64,
pub instant_reward_duration_sec: u64,
pub instant_reward_gems_prices: Vec<i64>,
pub afk_instant_ad_daily_limit: u64,
}Fields
bundle_id: BundleIdmin_required_time_sec: u64max_possible_time_sec: u64bonus_calculation_rate_sec: NonZeroU64instant_reward_duration_sec: u64instant_reward_gems_prices: Vec<i64>afk_instant_ad_daily_limit: u64Trait Implementations
Sourceimpl Clone for AfkRewardsSettings
impl Clone for AfkRewardsSettings
Sourcefn clone(&self) -> AfkRewardsSettings
fn clone(&self) -> AfkRewardsSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AfkRewardsSettings
impl Debug for AfkRewardsSettings
Sourceimpl<'de> Deserialize<'de> for AfkRewardsSettings
impl<'de> Deserialize<'de> for AfkRewardsSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AfkRewardsSettings
impl JsonSchema for AfkRewardsSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AfkRewardsSettings
impl Serialize for AfkRewardsSettings
Sourceimpl Tsify for AfkRewardsSettings
impl Tsify for AfkRewardsSettings
const DECL: &'static str = "export interface AfkRewardsSettings {\n bundle_id: BundleId;\n min_required_time_sec: number;\n max_possible_time_sec: number;\n bonus_calculation_rate_sec: NonZeroU64;\n instant_reward_duration_sec: number;\n instant_reward_gems_prices: number[];\n afk_instant_ad_daily_limit: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>